export const CHART_CONTAINER_HEIGHT = 300;

export const INNER_CHART_HEIGHT = 200;

export const X_AXIS_LABEL_ROTATION = 45;

export const X_AXIS_TITLE_OFFSET = 60;

export const ONE_WEEK_AGO_DAYS = 7;
export const ONE_MONTH_AGO_DAYS = 31;
export const ONE_YEAR_AGO_DAYS = 365;

export const DATE_RANGE_LAST_WEEK = 7;
export const DATE_RANGE_LAST_30_DAYS = 30;
export const DATE_RANGE_LAST_90_DAYS = 90;
export const DATE_RANGE_LAST_180_DAYS = 180;

export const DEFAULT = 'default';
export const PARSE_FAILURE = 'parse_failure';
export const LOAD_ANALYTICS_FAILURE = 'load_analytics_failure';
export const LOAD_PIPELINES_FAILURE = 'load_analytics_failure';
export const UNSUPPORTED_DATA = 'unsupported_data';

export const SNOWPLOW_LABEL = 'redis_hll_counters.analytics.analytics_total_unique_counts_monthly';
export const SNOWPLOW_SCHEMA = 'iglu:com.gitlab/gitlab_service_ping/jsonschema/1-0-1';
export const SNOWPLOW_DATA_SOURCE = 'redis_hll';
